==> openshift-sync-1.0.38-sources.jar: io/fabric8/jenkins/openshiftsync/BuildToActionMapper.java <==
/**
 * Copyright (C) 2017 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.fabric8.jenkins.openshiftsync;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import hudson.model.CauseAction;
import hudson.model.ParametersAction;

public class BuildToActionMapper {

    private static Map<String, ParametersAction> buildToParametersMap;
    private static Map<String, CauseAction> buildToCauseMap;

    private BuildToActionMapper() {
    }

    static synchronized void initialize() {
        if (buildToParametersMap == null) {
            buildToParametersMap = new ConcurrentHashMap<String, ParametersAction>();
        }
        if (buildToCauseMap == null) {
            buildToCauseMap = new ConcurrentHashMap<String, CauseAction>();
        }
    }

    static synchronized void addParameterAction(String buildId,
            ParametersAction params) {
        buildToParametersMap.put(buildId, params);
    }

    static synchronized ParametersAction removeParameterAction(String buildId) {
        return buildToParametersMap.remove(buildId);
    }

    static synchronized void addCauseAction(String buildId, CauseAction cause) {
        buildToCauseMap.put(buildId, cause);
    }

    static synchronized CauseAction removeCauseAction(String buildId) {
        return buildToCauseMap.remove(buildId);
    }

}

==> openshift-sync-1.0.49-sources.jar: io/fabric8/jenkins/openshiftsync/BuildToActionMapper.java <==
/**
 * Copyright (C) 2017 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.fabric8.jenkins.openshiftsync;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import hudson.model.CauseAction;
import hudson.model.ParametersAction;

public class BuildToActionMapper {

    private static Map<String, ParametersAction> buildToParametersMap = new ConcurrentHashMap<String, ParametersAction>();;
    private static Map<String, CauseAction> buildToCauseMap = new ConcurrentHashMap<String, CauseAction>();

    private BuildToActionMapper() {
    }

    static synchronized void initialize() {
        if (buildToParametersMap == null) {
            buildToParametersMap = new ConcurrentHashMap<String, ParametersAction>();
        }
        if (buildToCauseMap == null) {
            buildToCauseMap = new ConcurrentHashMap<String, CauseAction>();
        }
    }

    static synchronized void addParameterAction(String buildId, ParametersAction params) {
        buildToParametersMap.put(buildId, params);
    }

    static synchronized ParametersAction removeParameterAction(String buildId) {
        return buildToParametersMap.remove(buildId);
    }

    static synchronized void addCauseAction(String buildId, CauseAction cause) {
        buildToCauseMap.put(buildId, cause);
    }

    static synchronized CauseAction removeCauseAction(String buildId) {
        return buildToCauseMap.remove(buildId);
    }

}
